==> apache-superset-1.5.3-source.tar.gz: apache-superset-1.5.3rc1/superset-frontend/plugins/plugin-chart-echarts/test/Gauge/buildQuery.test.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import buildQuery from '../../src/Gauge/buildQuery';

describe('Gauge buildQuery', () => {
  const baseFormData = {
    datasource: '5__table',
    metric: 'foo',
    viz_type: 'my_chart',
  };

  it('should build query fields with no group by column', () => {
    const formData = { ...baseFormData, groupby: undefined };
    const queryContext = buildQuery(formData);
    const [query] = queryContext.queries;
    expect(query.groupby).toEqual([]);
  });

  it('should build query fields with single group by column', () => {
    const formData = { ...baseFormData, groupby: ['foo'] };
    const queryContext = buildQuery(formData);
    const [query] = queryContext.queries;
    expect(query.groupby).toEqual(['foo']);
  });

  it('should build query fields with multiple group by columns', () => {
    const formData = { ...baseFormData, groupby: ['foo', 'bar'] };
    const queryContext = buildQuery(formData);
    const [query] = queryContext.queries;
    expect(query.groupby).toEqual(['foo', 'bar']);
  });
});

==> apache-superset-4.1.2-source.tar.gz: apache-superset-4.1.2rc1/superset-frontend/plugins/plugin-chart-echarts/test/Gauge/buildQuery.test.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import buildQuery from '../../src/Gauge/buildQuery';

describe('Gauge buildQuery', () => {
  const baseFormData = {
    datasource: '5__table',
    metric: 'foo',
    viz_type: 'my_chart',
  };

  it('should build query fields with no group by column', () => {
    const formData = { ...baseFormData, groupby: undefined };
    const queryContext = buildQuery(formData);
    const [query] = queryContext.queries;
    expect(query.columns).toEqual([]);
  });

  it('should build query fields with single group by column', () => {
    const formData = { ...baseFormData, groupby: ['foo'] };
    const queryContext = buildQuery(formData);
    const [query] = queryContext.queries;
    expect(query.columns).toEqual(['foo']);
  });

  it('should build query fields with multiple group by columns', () => {
    const formData = { ...baseFormData, groupby: ['foo', 'bar'] };
    const queryContext = buildQuery(formData);
    const [query] = queryContext.queries;
    expect(query.columns).toEqual(['foo', 'bar']);
  });
});
